#!/usr/bin/env python
"""
Licensed to the Apache Software Foundation (ASF) under one
or more contributor license agreements.  See the NOTICE file
distributed with this work for additional information
regarding copyright ownership.  The ASF licenses this file
to you under the Apache License, Version 2.0 (the
"License"); you may not use this file except in compliance
with the License.  You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

"""

import os
import errno


def symlink_create(target, link):
  """Create a symlink if it doesn't exist, update the symlink if it already exists
  the update only happens if the link is really a symlink (do not remove a folder)

  :param target: the folder to link to (should exist)
  :param link: the link to create linking to the target
  :return:
  """
  try:
    os.symlink(target, link)
  except OSError, e:
    if e.errno == errno.EEXIST:
      # only proceed if it's really a link
      if os.path.islink(link):
        os.remove(link)
        os.symlink(target, link)
      else:
        raise e
    else:
      raise e


def symlink_realpath(link):
  """return the real path of the symlink, None otherwise

  :param link:
  :return:
  """
  if symlink_valid(link):
    return os.path.realpath(link)
  return None


def symlink_valid(link):
  """return True if the link is really a symlink, and if the linked folder exists

  :param link: the symlink to check for validity
  :return: True or False
  """
  if os.path.islink(link):
    if os.path.exists(link):
      return True

  return False



